@@ -6,20 +6,28 @@
 #include <string.h>
 #include <xtekplot1.h>
 
+const int MAXP=400,MAXD=200;
+
 main(int argc,char *argv[])
 {
  double xmin=0,ymin=0,xmax=1.2,ymax=1.0;
- char name[600]="testdir/my.setting";
- char *text="Lade Datei";
- char filt[200]="*.s*";
+ char name[MAXP]="testdir/my.setting";
+ char text[80]="Lade Datei";
+ char filt[MAXD]="*.s*";
+ int sprache=SPRACHE_DEUTSCH;
  int ok;
  if(argc>=2) strcpy(name,argv[1]);
  if(argc>=3) strcpy(text,argv[2]);
  if(argc>=4) strcpy(filt,argv[3]);
+ if(argc>=5) sscanf(argv[4],"%d",&sprache);
+ if(sprache==0)
+  {printf("Sprache (%d=deutsch, %d=english):",SPRACHE_DEUTSCH,SPRACHE_ENGLISH);
+   scanf("%d",&sprache);
+  }
  if(strcmp(filt,"NULL")==0)
-   ok=nachfilenamefragen(text,name,600);
+   ok=nachfilenamefragen(text,name,MAXP);
  else
-   ok=nachfilenamefragen(text,name,600,SPRACHE_DEUTSCH,filt);
+   ok=nachfilenamefragen(text,name,MAXP,sprache,filt);
  if(ok) printf("name='%s' ok.\n",name);
  else printf("name='%s' cancel.\n",name);
 }
